@@ -14,6 +14,7 @@
 
 import os
 import re
+import sys
 from concurrent.futures._base import Future
 from typing import List, Set
 
@@ -91,11 +92,11 @@ class Browser(DynamicCore):
 
     == Contexts ==
 
-    A *context* corresponds to several independent incognito browsers in Chrome
-    that do not share cookies, sessions or profile settings.
-    Compared to Selenium, these do *not* require their own browser process!
-    Therefore, to get a clean environment the tests shall just close the current
-    context and open a new context.
+    A *context* corresponds to set of independent incognito pages in a browser
+    that share cookies, sessions or profile settings. Pages in two separate
+    contexts do not share cookies, sessions or profile settings.
+    Compared to Selenium, these do *not* require their own browser process.
+    To get a clean environment a test can just open a new context.
     Due to this new independent browser sessions can be opened with
     Robot Framework Browser about 10 times faster than with Selenium by
     just opening a `New Context` within the opened browser.
@@ -112,7 +113,7 @@ class Browser(DynamicCore):
 
     == Pages ==
 
-    A *page* does contain the content of the loaded web site.
+    A *page* does contain the content of the loaded web site and has a browsing history.
     Pages and browser tabs are the same.
 
     Typical usage could be:
@@ -123,10 +124,8 @@ class Browser(DynamicCore):
     |     New Page       https://marketsquare.github.io/robotframework-browser/Browser.html
     |     Get Title      ==    Browser
 
-    There are shortcuts to open new pages together with new browsers but the offer less control.
-
     The `Open Browser` keyword opens a new browser, a new context and a new page.
-    This keyword is usefull for quick experiments or debugging sessions.
+    This keyword is useful for quick experiments or debugging sessions.
 
     When a `New Page` is called without an open browser, `New Browser`
     and `New Context` are executed with default values first.
@@ -136,8 +135,8 @@ class Browser(DynamicCore):
     the test. The browser process remains open and will be closed at the end of
     execution.
 
-    Each Browser, Context and Page has a unique ID with which they can be adressed.
-    A full catalog of what is open can be recieved by `Get Browser Catalog` as dictionary.
+    Each Browser, Context and Page has a unique ID with which they can be addressed.
+    A full catalog of what is open can be received by `Get Browser Catalog` as dictionary.
 
 
 
@@ -523,6 +522,7 @@ class Browser(DynamicCore):
     ROBOT_LIBRARY_SCOPE = "GLOBAL"
     SUPPORTED_BROWSERS = ["chromium", "firefox", "webkit"]
     _auto_closing_level: AutoClosingLevel
+    _pause_on_failure: Set["Browser"] = set()
 
     def __init__(
         self,
@@ -559,6 +559,7 @@ class Browser(DynamicCore):
         self.ROBOT_LIBRARY_LISTENER = self
         self._execution_stack: List[object] = []
         self._running_on_failure_keyword = False
+        self._pause_on_failure = set()
         self.run_on_failure_keyword = (
             None if is_falsy(run_on_failure) else run_on_failure
         )
@@ -658,6 +659,13 @@ class Browser(DynamicCore):
             return DynamicCore.run_keyword(self, name, args, kwargs)
         except AssertionError as e:
             self.keyword_error()
+            if self._pause_on_failure:
+                sys.__stdout__.write(f"\n[ FAIL ] {e}")
+                sys.__stdout__.write(
+                    "\n[Paused on failure] Press Enter to continue..\n"
+                )
+                sys.__stdout__.flush()
+                input()
             raise e
 
     def start_keyword(self, name, attrs):
