@@ -20,7 +20,13 @@ from robotlibcore import keyword  # type: ignore
 
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
-from ..utils import logger
+from ..utils import (
+    exec_scroll_function,
+    get_abs_scroll_coordinates,
+    get_rel_scroll_coordinates,
+    logger,
+    timestr_to_millisecs,
+)
 from ..utils.data_types import (
     BoundingBox,
     Coordinates,
@@ -31,9 +37,9 @@ from ..utils.data_types import (
     MouseButton,
     MouseButtonAction,
     MouseOptionsDict,
+    ScrollBehavior,
     SelectAttribute,
 )
-from ..utils.time_conversion import timestr_to_millisecs
 
 
 class Interaction(LibraryComponent):
@@ -47,6 +53,7 @@ class Interaction(LibraryComponent):
         character in the text.
 
         ``selector`` <str> Selector of the text field. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``text`` <str> Text for the text field. **Required**
 
@@ -75,6 +82,7 @@ class Interaction(LibraryComponent):
         you can pass an empty string as ``text`` to clear the input field.
 
         ``selector`` <str> Selector of the text field. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``text`` <str> Text for the text field. **Required**
 
@@ -87,6 +95,7 @@ class Interaction(LibraryComponent):
         """Clears the text field found by ``selector``.
 
         ``selector`` <str> Selector of the text field. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         See `Type Text` for emulating typing text character by character.
         See `Fill Text` for direct filling of the full text at once.
@@ -106,6 +115,7 @@ class Interaction(LibraryComponent):
         text to be written into the text field.
 
         ``selector`` <str> Selector of the text field. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``secret`` <str> Secret text for the text field. **Required**
 
@@ -129,6 +139,7 @@ class Interaction(LibraryComponent):
         text to be written into the text field.
 
         ``selector`` <str> Selector of the text field. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``secret`` <str> Secret text for the text field. **Required**
 
@@ -141,6 +152,7 @@ class Interaction(LibraryComponent):
         """Types the given key combination into element found by ``selector``.
 
         ``selector`` <str> Selector of the text field. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         Supports values like "a, b" which will be automatically typed.
         .
@@ -166,6 +178,7 @@ class Interaction(LibraryComponent):
         """Clicks the element found by ``selector``.
 
         ``selector`` <str> Selector of the element to click. **Required**
+        See the `Finding elements` section for details about the selectors.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.Click(Request().ElementSelector(selector=selector))
@@ -193,20 +206,21 @@ class Interaction(LibraryComponent):
         - Use `Mouse Move` to hover over the center of the element, or the specified ``position``.
 
         ``selector`` <str> Selector element to click. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``button`` < ``left`` | ``middle`` |  ``right``> The button that shall be used for clicking.
 
         ``clickCount`` <int> How many time shall be clicked.
 
-        ``delay`` <robot time str> Time to wait between mousedown and mouseup and next click.
+        ``delay`` <robot time str> Time to wait between mouse-down and mouse-up and next click.
 
-        *Caution: be aware that if the delal leats to a total time that exceets the timeout, the keyword fails*
+        *Caution: be aware that if the delay leads to a total time that exceeds the timeout, the keyword fails*
 
         ``position_x`` & ``position_y`` <float> A point to click relative to the
-        top-left corner of element boundingbox. Only positive values within the boundingbox are allowed.
+        top-left corner of element bounding-box. Only positive values within the bounding-box are allowed.
         If not specified, clicks to some visible point of the element.
 
-        *Caution: even with 0, 0 might click a few pixels off from the corner of the boundingbox. Click uses detection to find the first clickable point.*
+        *Caution: even with 0, 0 might click a few pixels off from the corner of the bounding-box. Click uses detection to find the first clickable point.*
 
         ``force`` <bool> Set to True to skip Playwright's [https://github.com/microsoft/playwright/blob/master/docs/actionability.md | Actionability checks].
 
@@ -255,25 +269,26 @@ class Interaction(LibraryComponent):
         - Wait for actionability checks on the matched element, unless ``force`` option is set. If the element is detached during the checks, the whole action is retried.
         - Scroll the element into view if needed.
         - Use `Mouse Button` to click in the center of the element, or the specified position.
-        - Wait for initiated navigations to either succeed or fail, unless ``noWaitAfter`` option is set.
+        - Wait for initiated navigation to either succeed or fail, unless ``noWaitAfter`` option is set.
 
         ``selector`` <str> Selector element to click. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``button`` < ``left`` | ``right`` | ``middle`` > Defaults to ``left`` if invalid.
 
         ``click_count`` <int> Defaults to 1.
 
-        ``delay`` <robot time str> Time to wait between mousedown and mouseup.
+        ``delay`` <robot time str> Time to wait between mouse-down and mouse-up.
         Defaults to 0.
 
         ``position_x`` & ``position_y`` <int> A point to click relative to the
-        top-left corner of element boundingbox. Only positive values within the boundingbox are allowed.
+        top-left corner of element bounding-box. Only positive values within the bounding-box are allowed.
         If not specified, clicks to some visible point of the element.
 
         ``force`` <bool> Set to True to skip Playwright's [https://github.com/microsoft/playwright/blob/master/docs/actionability.md | Actionability checks].
 
-        ``noWaitAfter`` <bool> Actions that initiate navigations are waiting for
-        these navigations to happen and for pages to start loading.
+        ``noWaitAfter`` <bool> Actions that initiate navigation, are waiting for
+        these navigation to happen and for pages to start loading.
         You can opt out of waiting via setting this flag.
         You would only need this option in the exceptional cases such as navigating
         to inaccessible pages. Defaults to ``False``.
@@ -304,6 +319,7 @@ class Interaction(LibraryComponent):
         """Moves focus on to the element found by ``selector``.
 
         ``selector`` <str> Selector of the element. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         If there's no element matching selector, the method waits until a
         matching element appears in the DOM. Timeouts after 10 seconds.
@@ -312,11 +328,103 @@ class Interaction(LibraryComponent):
             response = stub.Focus(Request().ElementSelector(selector=selector))
             logger.debug(response.log)
 
+    @keyword(tags=["Setter", "PageContent"])
+    def scroll_to(
+        self,
+        selector: Optional[str] = None,
+        vertical: str = "top",
+        horizontal: str = "left",
+        behavior: ScrollBehavior = ScrollBehavior.auto,
+    ):
+        """Scrolls an element or the page to an absolute position based on given coordinates.
+
+        ``selector`` <str> Selector of the element. If the selector is ``${None}`` or ``${Empty}``
+        the page itself is scrolled.
+        See the `Finding elements` section for details about the selectors.
+
+        ``vertical`` <str> defines where to scroll vertically.
+        It can be a positive number, like ``300``.
+        It can be a percentage value of the absolute scrollable size, like ``50%``.
+        It can be a string defining that top or the bottom of the scroll area. < ``top`` | ``bottom`` >
+        _Be aware that some pages do lazy loading and load more content once you scroll down._
+        Bottom defines the current known bottom coordinate.
+
+        ``horizontal`` <str> defines where to scroll horizontally.
+        Works same as vertical but defines < ``left`` | ``right`` > as start and end.
+
+        ``behavior`` <str> defines whether the scroll happens directly or it scrolls smoothly.
+        < ``auto`` | ``smooth`` >
+        """
+        scroll_size = self.library.get_scroll_size(selector)
+        scroll_width = scroll_size["width"]
+        scroll_height = scroll_size["height"]
+        client_size = self.library.get_client_size(selector)
+        client_width = client_size["width"]
+        client_height = client_size["height"]
+        vertical_px = get_abs_scroll_coordinates(
+            vertical, scroll_height - client_height, "top", "bottom"
+        )
+        horizontal_px = get_abs_scroll_coordinates(
+            horizontal, scroll_width - client_width, "left", "right"
+        )
+        exec_scroll_function(
+            self,
+            f'scrollTo({{"left": {horizontal_px}, "top": {vertical_px}, "behavior": "{behavior.name}"}})',
+            selector,
+        )
+
+    @keyword(tags=["Setter", "PageContent"])
+    def scroll_by(
+        self,
+        selector: Optional[str] = None,
+        vertical: str = "height",
+        horizontal: str = "0",
+        behavior: ScrollBehavior = ScrollBehavior.auto,
+    ):
+        """Scrolls an element or the page relative from current position by the given values.
+
+        ``selector`` <str> Selector of the element. If the selector is ``${None}`` or ``${Empty}``
+        the page itself is scrolled.
+        See the `Finding elements` section for details about the selectors.
+
+        ``vertical`` <str> defines how far and in which direction to scroll vertically.
+        It can be a positive or negative number. Positive scrolls down, like ``50``, negative scrolls up, like ``-50``.
+        It can be a percentage value of the absolute scrollable size, like ``9.95%`` or negative like ``-10%``.
+        It can be the string ``height`` to defining to scroll exactly one visible height down or up with ``-height``.
+        _Be aware that some pages do lazy loading and load more content once you scroll down._
+        The percentage of the current scrollable height is used and may change.
+
+        ``horizontal`` <str> defines where to scroll horizontally.
+        Works same as vertical but defines positive values for right and negative values for left.
+        ``width`` defines to scroll exactly one visible range to the right.
+
+        ``behavior`` <str> defines whether the scroll happens directly or it scrolls smoothly.
+        < ``auto`` | ``smooth`` >
+        """
+        scroll_size = self.library.get_scroll_size(selector)
+        scroll_width = scroll_size["width"]
+        scroll_height = scroll_size["height"]
+        client_size = self.library.get_client_size(selector)
+        client_width = client_size["width"]
+        client_height = client_size["height"]
+        vertical_px = get_rel_scroll_coordinates(
+            vertical, scroll_height - client_height, client_height, "height"
+        )
+        horizontal_px = get_rel_scroll_coordinates(
+            horizontal, scroll_width - client_width, client_width, "width"
+        )
+        exec_scroll_function(
+            self,
+            f'scrollBy({{"left": {horizontal_px}, "top": {vertical_px}, "behavior": "{behavior.name}"}})',
+            selector,
+        )
+
     @keyword(tags=["Setter", "PageContent"])
     def check_checkbox(self, selector: str):
         """Checks the checkbox or selects radio button found by ``selector``.
 
         ``selector`` <str> Selector of the checkbox. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         Does nothing if the element is already checked/selected.
         """
@@ -329,6 +437,7 @@ class Interaction(LibraryComponent):
         """Unchecks the checkbox found by ``selector``.
 
         ``selector`` <str> Selector of the checkbox. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         Does nothing if the element is not checked/selected.
         """
@@ -343,6 +452,7 @@ class Interaction(LibraryComponent):
         """Selects options from select element found by ``selector``.
 
         ``selector`` <str> Selector of the select tag. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         Matches based on the chosen attribute with list of ``values``.
         Possible attributes to match options by:
@@ -372,6 +482,7 @@ class Interaction(LibraryComponent):
         """Deselects all options from select element found by ``selector``.
 
         ``selector`` <str> Selector of the select tag. **Required**
+        See the `Finding elements` section for details about the selectors.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.DeselectOption(Request().ElementSelector(selector=selector))
@@ -505,6 +616,7 @@ class Interaction(LibraryComponent):
     def drag_and_drop(self, selector_from: str, selector_to: str, steps: int = 1):
         """Executes a Drag&Drop operation from the element selected by ``selector_from``
         to the element selected by ``selector_to``.
+        See the `Finding elements` section for details about the selectors.
 
         First it moves the mouse to the start-point,
         then presses the left mouse button,
