@@ -56,8 +56,11 @@ class PlaywrightState(LibraryComponent):
         url: Optional[str] = None,
         browser: SupportedBrowsers = SupportedBrowsers.chromium,
         headless: bool = False,
+        pause_on_failure: bool = True,
     ):
-        """Opens a new browser instance.
+        """Opens a new browser instance. Use this keyword for quick experiments or debugging sessions.
+        Use `New Page` directly instead of `Open Browser` for production and automated execution.
+        See `Browser, Context and Page` for more information about Browser and related concepts.
 
         Creates a new browser, context and page with specified settings.
             Only supports some of the settings Create _ Keywords do
@@ -73,16 +76,23 @@ class PlaywrightState(LibraryComponent):
         | webkit          | [https://webkit.org/|webkit]                         |
 
         ``headless`` <bool> If set to False, a GUI is provided otherwise it is hidden. Defaults to False.
-        """
 
-        self.new_browser(browser, headless=headless)
+        ``pause_on_failure`` <bool> Stop execution when failure detected and leave browser open. Defaults to True.
+        """
+        logger.warn(
+            "Open Browser is for quick experimentation and debugging only. Use New Page for production."
+        )
+        browser_id = self.new_browser(browser, headless=headless)
         self.new_context()
         self.new_page(url)
+        if pause_on_failure:
+            self.library._pause_on_failure.add(browser_id)
 
     @keyword(tags=["Setter", "BrowserControl"])
     def close_browser(self, browser: str = "CURRENT"):
         """Closes the current browser. Activated browser is set to first active browser.
         Closes all context and pages belonging to this browser.
+        See `Browser, Context and Page` for more information about Browser and related concepts.
 
         ``browser`` < ``CURRENT`` | ``ALL`` | str > If value is not ``CURRENT``
         it should be a string referencing the id of the browser to be closed.
@@ -91,18 +101,22 @@ class PlaywrightState(LibraryComponent):
         with self.playwright.grpc_channel() as stub:
             if browser == "ALL":
                 response = stub.CloseAllBrowsers(Request().Empty())
+                self.library._pause_on_failure.clear()
                 logger.info(response.log)
                 return
             if browser != "CURRENT":
                 self.switch_browser(browser)
 
             response = stub.CloseBrowser(Request.Empty())
+            closed_browser_id = response.body
+            self.library._pause_on_failure.discard(closed_browser_id)
             logger.info(response.log)
 
     @keyword(tags=["Setter", "BrowserControl"])
     def close_context(self, context: str = "CURRENT", browser: str = "CURRENT"):
         """Closes a Context. Activated context is set to first active context.
         Closes pages belonging to this context.
+        See `Browser, Context and Page` for more information about Context and related concepts.
 
         ``context`` < ``CURRENT`` | ``ALL`` | str > Close context with specified id. If ``ALL``
         is passed, all contexts of the specified browser are closed. Defaults to CURRENT.
@@ -153,6 +167,7 @@ class PlaywrightState(LibraryComponent):
     ):
         """Closes the ``page`` in ``context`` in ``browser``. Defaults to current for all three.
         Activated page is set to first active page.
+        See `Browser, Context and Page` for more information about Page and related concepts.
 
         ``page`` < ``CURRENT`` | ``ALL`` | str > Id of the page to close. If value is not "CURRENT"
         it should be a string referencing the id of the context where to close page.
@@ -224,8 +239,9 @@ class PlaywrightState(LibraryComponent):
         env: Optional[Dict] = None,
         devtools: bool = False,
         slowMo: str = "0 seconds",
-    ):
+    ) -> str:
         """Create a new playwright Browser with specified options.
+        See `Browser, Context and Page` for more information about Browser and related concepts.
 
         Returns a stable identifier for the created browser.
 
@@ -310,8 +326,9 @@ class PlaywrightState(LibraryComponent):
         colorScheme: Optional[ColorScheme] = None,
         hideRfBrowser: bool = False,
         defaultBrowserType: Optional[str] = None,
-    ):
+    ) -> str:
         """Create a new BrowserContext with specified options.
+        See `Browser, Context and Page` for more information about BrowserContext.
 
         Returns a stable identifier for the created context
         that can be used in `Switch Context`.
@@ -380,7 +397,7 @@ class PlaywrightState(LibraryComponent):
         See [https://github.com/microsoft/playwright/blob/master/docs/api.md#browsernewcontextoptions|Playwright browser.newContext]
         for a list of supported options.
 
-        If there's no open Browser will open one. Does not create pages.
+        If there's no open Browser this keyword will open one. Does not create pages.
         """
         params = locals_to_params(locals())
         options = json.dumps(params, default=str)
@@ -393,10 +410,14 @@ class PlaywrightState(LibraryComponent):
             return response.body
 
     @keyword(tags=["Setter", "BrowserControl"])
-    def new_page(self, url: Optional[str] = None):
+    def new_page(self, url: Optional[str] = None) -> str:
         """Open a new Page. A Page is the Playwright equivalent to a tab.
+        See `Browser, Context and Page` for more information about Page concept.
         Returns a stable identifier for the created page.
 
+        When a `New Page` is called without an open browser, `New Browser`
+        and `New Context` are executed with default values first.
+
         ``url`` <str> If specified it will open the new page to the specified URL.
 
         """
@@ -411,8 +432,9 @@ class PlaywrightState(LibraryComponent):
         self,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ):
+    ) -> Dict:
         """Returns all browsers, open contexts in them and open pages in these contexts.
+        See `Browser, Context and Page` for more information about these concepts.
 
         The data is parsed into a python list containing data representing the open Objects.
 
@@ -487,9 +509,10 @@ class PlaywrightState(LibraryComponent):
             )
 
     @keyword(tags=["Setter", "BrowserControl"])
-    def switch_browser(self, id: str):
+    def switch_browser(self, id: str) -> str:
         """Switches the currently active Browser to another open Browser.
         Returns a stable identifier for the previous browser.
+        See `Browser, Context and Page` for more information about Browser and related concepts.
 
         ``id`` <str> Id of the browser to be changed to. Starting at 0. **Required**
         """
@@ -499,9 +522,10 @@ class PlaywrightState(LibraryComponent):
             return response.body
 
     @keyword(tags=["Setter", "BrowserControl"])
-    def switch_context(self, id: str, browser: str = "CURRENT"):
+    def switch_context(self, id: str, browser: str = "CURRENT") -> str:
         """Switches the active BrowserContext to another open context.
         Returns a stable identifier for the previous context.
+        See `Browser, Context and Page` for more information about Context and related concepts.
 
         ``id`` <str> Id of the context to be changed to. Randomly generated UUID. **Required**
 
@@ -515,12 +539,19 @@ class PlaywrightState(LibraryComponent):
             return response.body
 
     @keyword(tags=["Setter", "BrowserControl"])
-    def switch_page(self, id: str, context: str = "CURRENT", browser: str = "CURRENT"):
+    def switch_page(
+        self, id: str, context: str = "CURRENT", browser: str = "CURRENT"
+    ) -> str:
         """Switches the active browser page to another open page by ``id`` or ``NEW``.
         Returns a stable identifier ``id`` for the previous page.
+        See `Browser, Context and Page` for more information about Page and related concepts.
 
         ``id`` < ``CURRENT`` | ``NEW `` | str> Id of the page to be changed to or
-        ``NEW`` for last opened page. With ``CURRENT`` you can get the ``id`` of the "CURRENT" page
+
+        ``NEW`` for a page opened after the current page. This may timeout if no new pages
+        exists before library timeout. See `Set Browser Timeout` for how to change the timeout.
+
+        With ``CURRENT`` you can get the ``id`` of the "CURRENT" page
         **Required**
 
         ``context`` < ``CURRENT`` | str> Switch page in specified context. If value is not "CURRENT"
@@ -537,13 +568,15 @@ class PlaywrightState(LibraryComponent):
 
             self._correct_browser(browser)
             self._correct_context(context)
-            response = stub.SwitchPage(Request().Index(index=id))
+            timeout = timestr_to_millisecs(self.timeout)
+            response = stub.SwitchPage(Request().IdWithTimeout(id=id, timeout=timeout))
             logger.info(response.log)
             return response.body
 
     @keyword(tags=["Getter", "BrowserControl"])
-    def get_browser_ids(self, browser: SelectionType = SelectionType.ALL):
+    def get_browser_ids(self, browser: SelectionType = SelectionType.ALL) -> List:
         """Returns a list of ids from open browsers.
+        See `Browser, Context and Page` for more information about Browser and related concepts.
 
 
         ``browser`` < ``ALL`` | ``ACTIVE`` | ``CURRENT`` > Defaults to ``ALL``
@@ -565,8 +598,9 @@ class PlaywrightState(LibraryComponent):
         self,
         context: SelectionType = SelectionType.ALL,
         browser: SelectionType = SelectionType.ALL,
-    ):
+    ) -> List:
         """Returns a list of context ids based on the browser selection.
+        See `Browser, Context and Page` for more information about Context and related concepts.
 
 
         ``context`` < ``ALL`` | ``ACTIVE`` > Defaults to ``ALL``
@@ -608,8 +642,9 @@ class PlaywrightState(LibraryComponent):
         page: SelectionType = SelectionType.ALL,
         context: SelectionType = SelectionType.ALL,
         browser: SelectionType = SelectionType.ALL,
-    ):
+    ) -> List:
         """Returns a list of page ids based on the context and browser selection.
+        See `Browser, Context and Page` for more information about Page and related concepts.
 
 
         ``page`` < ``ALL`` | ``ACTIVE`` >
