@@ -40,6 +40,7 @@ class Waiter(LibraryComponent):
         If the selector doesn't satisfy the condition within the timeout the keyword will FAIL.
 
         ``selector`` <str> Selector of the corresponding object. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``state`` Defaults to visible. Possible states are:
         - ``attached``: to be present in DOM.
@@ -113,6 +114,7 @@ class Waiter(LibraryComponent):
         ``selector`` <str> Selector to resolve and pass to the JavaScript function. This will be the first
         argument the function receives. If given a selector a function is necessary, with an argument
         to capture the elementhandle. For example ``(element) => document.activeElement === element``
+        See the `Finding elements` section for details about the selectors.
 
         ``polling`` <str> Default polling value of "raf" polls in a callback for ``requestAnimationFrame``.
         Any other value for polling will be parsed as a robot framework time for interval between polls.
@@ -133,14 +135,16 @@ class Waiter(LibraryComponent):
             options_json = json.dumps(options)
             response = stub.WaitForFunction(
                 Request().WaitForFunctionOptions(
-                    script=function, selector=selector, options=options_json,
+                    script=function,
+                    selector=selector,
+                    options=options_json,
                 )
             )
             logger.debug(response.json)
             logger.info(response.log)
 
     @keyword(tags=["Wait", "BrowserControl"])
-    def wait_for_download(self, saveAs: str = ""):
+    def wait_for_download(self, saveAs: str = "") -> str:
         """Waits for next download event on page. Returns file path to downloaded file.
 
         To enable downloads context's ``acceptDownloads`` needs to be true.
