@@ -21,9 +21,16 @@ from .data_types import (
     CookieType,
     ElementState,
     RequestMethod,
+    SelectAttribute,
+    SelectionType,
     SupportedBrowsers,
     ViewportDimensions,
 )
+from .js_utilities import (
+    exec_scroll_function,
+    get_abs_scroll_coordinates,
+    get_rel_scroll_coordinates,
+)
 from .meta_python import find_by_id, locals_to_params
 from .misc import find_free_port, get_normalized_keyword, is_same_keyword
 from .robot_booleans import is_falsy, is_truthy
